@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'pathname'
 require 'rake'
 test_dir = Pathname.new File.dirname(__FILE__)
@@ -50,6 +52,12 @@ FileUtils.mkdir_p 'log'
 ActiveRecord::Base.logger = Logger.new("log/test.log")
 ActiveRecord::Base.logger.level = Logger::DEBUG
 
+if ActiveRecord.respond_to?(:use_yaml_unsafe_load)
+  ActiveRecord.use_yaml_unsafe_load = true
+elsif ActiveRecord::Base.respond_to?(:use_yaml_unsafe_load)
+  ActiveRecord::Base.use_yaml_unsafe_load = true
+end
+
 if ENV['AR_VERSION'].to_f >= 6.0
   yaml_config = if Gem::Version.new(Psych::VERSION) >= Gem::Version.new('3.2.1')
     YAML.safe_load_file(test_dir.join("database.yml"), aliases: true)[adapter]
